using System;
using System.Collections.ObjectModel;
using System.Linq;
using Avalonia;
using Avalonia.Controls;
using Avalonia.Controls.Templates;
using Avalonia.Data;
using Avalonia.Markup.Xaml;
using GLTFViewer.Engine;
using GLTFViewer.Engine.Ui;

namespace GLTFViewer;

public partial class MainUI : UserControl
{

    private SceneTree _sceneTree; 
    
    private TreeView _sceneTreeView;
    private TreeView _propertyTreeView;
    

    
    
    public MainUI()
    {
        InitializeComponent();
        
        _sceneTreeView = SceneTreeView;
        _propertyTreeView = PropertyTreeView;
        _sceneTree = new SceneTree(_sceneTreeView);
        
        _sceneTreeView.SelectionChanged += PropertyTreeViewOnSelectionChanged;
        
        var random = new Random();
        Node previousNode = _sceneTree.Root;

        for (int i = 0; i < 20; i++)
        {
            var newNode = new Node($"child{i}");
            if (random.Next(2) == 0)
            {
                previousNode.AddChild(newNode);
            }
            else
            {
                _sceneTree.Root.AddChild(newNode);
            }
            previousNode = newNode;
        }
    }

    private void PropertyTreeViewOnSelectionChanged(object? sender, SelectionChangedEventArgs e)
    {
        _propertyTreeView.ItemsSource = _sceneTreeView.SelectedItem is Node node ? node.Properties : null;
        _propertyTreeView.ItemTemplate = new FuncTreeDataTemplate<NodeProperty>(
            (property, _) =>
            {
                var textBlock = new TextBlock { Text = property.Name };
                return textBlock;
            },
            property => null
        );
    }
}